@@ -69,7 +69,7 @@ public:
     inline int whereAreYou (int & x, int & y) {
                             x = gridX; y = gridY; return pointsPerCell; }
 
-signals:
+Q_SIGNALS:
     /**
      * Requests the KGoldrunner game to add to the human player's score.
      *
@@ -219,7 +219,7 @@ public:
      */
     void             showState();
 
-signals:
+Q_SIGNALS:
     void             soundSignal (const int n, const bool onOff = true);
     void             invalidDig();	// Warning re dig while falling.
 
@@ -253,8 +253,6 @@ public:
      * @param j            The starting row-number (>=1).
      * @param pSpriteId    The sprite ID of the enemy, as used in animation.
      * @param pRules       The rules that apply to this game and level.
-     * @param pRandomGen   Random number generator: used to decide when to pick
-     *                     up or drop gold.
      */
     KGrEnemy (KGrLevelPlayer * pLevelPlayer, KGrLevelGrid * pGrid,
                  int i, int j, int pSpriteId, KGrRuleBook  * pRules);
